==> x_ite-4.7.15.jar: META-INF/resources/webjars/x_ite/4.7.15/src/x_ite/Configuration/ComponentInfoArray.js <==
/* -*- Mode: JavaScript; coding: utf-8; tab-width: 3; indent-tabs-mode: tab; c-basic-offset: 3 -*-
 *******************************************************************************
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * Copyright create3000, Scheffelstraße 31a, Leipzig, Germany 2011.
 *
 * All rights reserved. Holger Seelig <holger.seelig@yahoo.de>.
 *
 * The copyright notice above does not evidence any actual of intended
 * publication of such source code, and is an unpublished work by create3000.
 * This material contains CONFIDENTIAL INFORMATION that is the property of
 * create3000.
 *
 * No permission is granted to copy, distribute, or create derivative works from
 * the contents of this software, in whole or in part, without the prior written
 * permission of create3000.
 *
 * NON-MILITARY USE ONLY
 *
 * All create3000 software are effectively free software with a non-military use
 * restriction. It is free. Well commented source is provided. You may reuse the
 * source in any way you please with the exception anything that uses it must be
 * marked to indicate is contains 'non-military use only' components.
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * Copyright 2015, 2016 Holger Seelig <holger.seelig@yahoo.de>.
 *
 * This file is part of the X_ITE Project.
 *
 * X_ITE is free software: you can redistribute it and/or modify it under the
 * terms of the GNU General Public License version 3 only, as published by the
 * Free Software Foundation.
 *
 * X_ITE is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 * A PARTICULAR PURPOSE. See the GNU General Public License version 3 for more
 * details (a copy is included in the LICENSE file that accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version 3
 * along with X_ITE.  If not, see <http://www.gnu.org/licenses/gpl.html> for a
 * copy of the GPLv3 License.
 *
 * For Silvio, Joy and Adi.
 *
 ******************************************************************************/


define ([
	"x_ite/Configuration/ComponentInfo",
	"x_ite/Configuration/X3DInfoArray",
],
function (ComponentInfo,
          X3DInfoArray)
{
"use strict";

	function ComponentInfoArray (array)
	{
		const proxy = X3DInfoArray .call (this);

		for (const componentInfo of array)
			this .add (componentInfo .name, componentInfo);

		return proxy;
	}

	ComponentInfoArray .prototype = Object .assign (Object .create (X3DInfoArray .prototype),
	{
		constructor: ComponentInfoArray,
		getTypeName: function ()
		{
			return "ComponentInfoArray";
		},
		addBaseComponent: function (value)
		{
			this .add (value .name, new ComponentInfo (value .name, value .level, value .title, value .providerUrl));
		},
	});

	return ComponentInfoArray;
});

==> x_ite-5.0.3.jar: META-INF/resources/webjars/x_ite/5.0.3/src/x_ite/Configuration/ComponentInfoArray.js <==
/* -*- Mode: JavaScript; coding: utf-8; tab-width: 3; indent-tabs-mode: tab; c-basic-offset: 3 -*-
 *******************************************************************************
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * Copyright create3000, Scheffelstraße 31a, Leipzig, Germany 2011.
 *
 * All rights reserved. Holger Seelig <holger.seelig@yahoo.de>.
 *
 * The copyright notice above does not evidence any actual of intended
 * publication of such source code, and is an unpublished work by create3000.
 * This material contains CONFIDENTIAL INFORMATION that is the property of
 * create3000.
 *
 * No permission is granted to copy, distribute, or create derivative works from
 * the contents of this software, in whole or in part, without the prior written
 * permission of create3000.
 *
 * NON-MILITARY USE ONLY
 *
 * All create3000 software are effectively free software with a non-military use
 * restriction. It is free. Well commented source is provided. You may reuse the
 * source in any way you please with the exception anything that uses it must be
 * marked to indicate is contains 'non-military use only' components.
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * Copyright 2015, 2016 Holger Seelig <holger.seelig@yahoo.de>.
 *
 * This file is part of the X_ITE Project.
 *
 * X_ITE is free software: you can redistribute it and/or modify it under the
 * terms of the GNU General Public License version 3 only, as published by the
 * Free Software Foundation.
 *
 * X_ITE is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 * A PARTICULAR PURPOSE. See the GNU General Public License version 3 for more
 * details (a copy is included in the LICENSE file that accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version 3
 * along with X_ITE.  If not, see <http://www.gnu.org/licenses/gpl.html> for a
 * copy of the GPLv3 License.
 *
 * For Silvio, Joy and Adi.
 *
 ******************************************************************************/


define ([
   "x_ite/Configuration/ComponentInfo",
   "x_ite/Base/X3DInfoArray",
],
function (ComponentInfo,
          X3DInfoArray)
{
"use strict";

   function ComponentInfoArray (values)
   {
      return X3DInfoArray .call (this, values);
   }

   ComponentInfoArray .prototype = Object .assign (Object .create (X3DInfoArray .prototype),
   {
      constructor: ComponentInfoArray,
      getTypeName: function ()
      {
         return "ComponentInfoArray";
      },
      addComponent: function (value)
      {
         this .add (value .name, new ComponentInfo (value .name, value .level, value .title, value .providerUrl));
      },
   });

   for (const key of Reflect .ownKeys (ComponentInfoArray .prototype))
      Object .defineProperty (ComponentInfoArray .prototype, key, { enumerable: false });

   return ComponentInfoArray;
});
